import { newsletter } from "../../entity/newsletter";
import { NewsletterViewModel } from "../../viewmodel/admin/newsletter.models";
import QueryStoreFactory from "./queryStore";

export default abstract class NewsletterFactory {
  /**
   * @description map record to newsletter
   * @param {newsletter} record
   * @returns {NewsletterViewModel}
   */
  public static mapToSingle(record: newsletter): NewsletterViewModel {
    return {
      id: record.id,
      title: record.title,
      description: record.description,
      newsletterTitle: record.newsletterTitle,
      newsletterText: record.newsletterText,
      newsletterSignatur: record.newsletterSignatur,
      isSent: record.isSent,
      recipientsByQuery: record?.recipientsByQuery ? QueryStoreFactory.mapToSingle(record.recipientsByQuery) : null,
    };
  }

  /**
   * @description map records to newsletter
   * @param {Array<newsletter>} records
   * @returns {Array<NewsletterViewModel>}
   */
  public static mapToBase(records: Array<newsletter>): Array<NewsletterViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
